

%  Profile247; accesses and plots the CTD, XCP, LADCP  and
%  nutrient data from all of the stations of the  Discovery 247 
%  expedition to Faroe Bank Channel. 
%
%  by Jim Price, beginning October, 2002 with essential contributions 
%  from Deb West-Mack, Dan Torres, John Dunlap, James Girton, 
%  Cecilie Mauritzen, Tom Sanford, and the science party of Discovery 247.
%
%  vertical coordinate is depth, m (z < 0). pressures, db, are also
%  computed, (p > 0). all u,v are absolute. 
%
%  contact Jim Price, 508-289-2526, jprice@whoi.edu if you
%  have questions or comments.

clear all; close all; format compact

% the following path assignements will locate the data sets:
path(path, 'CTD')                    %  the ctd files are here
path(path, 'LADCP')                  %  the ladcp files
path(path, 'XCP\xcp-abs-2db\')       %  the xcp files
path(path, 'seawater')               %  Matlab seawater property scripts

%  requires the functions getlog, getctd, getxcp, getladcp, getnut
%  the ascii text file with the log data is log.txt;  to convert this to a
%  structure, use log2mat. the structure is saved in D247log.mat, also required. 
%  requires the figure file largebasemap.fig to make a station location plot.


% set default graphics things
set(0,'DefaultTextFontSize',12)
set(0,'DefaultAxesFontSize',12)
set(0,'DefaultAxesLineWidth',1.2)
set(0,'DefaultLineLineWidth',1.6)


m1 = input('  Enter the first station number  (the log sequence number)') 

for mm = m1:217     % the first data line is 2  
close all
  
isctdOK = 0;
isxcpOK = 0;
isladcpOK = 0;
isnutOK = 0;

seqno = -mm;  %  a negative value is a line number in the log file

%  get the station data from the log file.
[islogOK, statname, latd, latm, lond, lonm, time, date, botz, ctdno, xcpno, chat] = ...
            getlog(seqno);

ccc = [' station ' num2str(ctdno) '  ' statname  ' ' num2str(xcpno) ' ' time ' ' date  '  '];
ccd = [' lat = ' num2str(latd) ' ' num2str(latm) '  lon = ' ...
        num2str(lond) ' ' num2str(lonm) '  bottom depth  '  num2str(botz) ];
disp([ccc ccd])
disp([ '        comments ...' chat])
disp('  ')

lat = latd + latm/60.;
lon = lond + sign(lond)*lonm/60.;

        
zlim = 200*ceil(max(abs(botz))/200);

%  get XCP data use the following:
[isxcpOK, xcpdepth, xcpu, xcpv, xcptemp, day, clat, clon, cbotz] = getxcp(xcpno);

if isxcpOK == 1
%  plot the XCP data
cp = sw_pres(-xcpdepth, lat);     %  compute pressure from depth

figure(1)
clf reset
orient landscape

subplot(1,2,1)
plot(xcpu/100., xcpdepth, xcpv/100., xcpdepth)
grid
xlabel('East, North currents, m s^{-1}')
ylabel('depth, m')
tstr = ['XCP  ', num2str(xcpno)];
ht = title(tstr); 
set(ht, 'FontSize', 14)
legend('East', 'North')
axis([-1 1 -zlim 0])

subplot(1,2,2)
plot(xcptemp, xcpdepth)
hold on
plot(min(xcptemp), -botz, '*k')
xlabel('Temperature, C')
grid
axis([-2 12 -zlim 0])

%  make a 3-D figure of the XCP currents

figure(2)
clf reset

subplot(1,2,1)
nz = max(size(xcpu));
for j=nz:-4:1
z = xcpdepth(j);
u = xcpu(j)/100.;
v = xcpv(j)/100.;   
hold on
plot3([0 u], [0 v], [z z])
end
box on
grid
axis([-1 0.4 -0.7 0.7 -zlim 0])
hold on
plot3([0 0], [0 0], [min(xcpdepth) 0], 'r', 'LineWidth', 2)
xlabel('U, m s^{-1}')
ylabel('V, m s^{-1}')
zlabel('depth, m')
view( 30., 30.)

subplot(1,2,2)
plot(xcptemp, xcpdepth)
xlabel('Temperature, C')
grid
axis([-2 12 -zlim 0])

st = ['XCP  ', num2str(xcpno)];
hs = title(st);
set(hs, 'FontSize', 14)
end    %  if on isxcpOK ==1


% now go  get the CTD cast
[isctdOK, ctdtemp, ctdsal, ctdoxygen, ctdpress] = getctd(ctdno);

if isctdOK == 1
ctdtheta = sw_ptmp(ctdsal, ctdtemp, ctdpress, 0.);
ctddensity = sw_dens0(ctdsal, ctdtemp);
ctddensity = ctddensity - 1000;
ctddepth = -sw_dpth(ctdpress, lat);

figure(3)
clf reset

subplot(2,2,1)
plot(ctdtemp, ctddepth)
hold on
plot(min(ctdtemp), -botz, '*k')
xlabel('pot. temperature, C')
ylabel('depth, m')
axis([-2 10 -zlim 0])
grid
st = ['CTD ', num2str(ctdno)]; 
hs = title(st);
set(hs, 'FontSize', 14)

subplot(2,2,2)
plot(ctdsal, ctddepth)
xlabel('salinity')
axis([34.5 35.5 -zlim 0])
grid

subplot(2,2,3)
plot(ctddensity, ctddepth)
xlabel('pot. density, kg m^{-3}')
ylabel('depth, m')
axis([27 28.5 -zlim 0])
grid

subplot(2,2,4)
plot(ctdoxygen, ctddepth)
xlabel('oxygen, \mu M kg^{-1}')
axis([240 320 -zlim 0])
grid

end   %  if on isctdOK ==1

%  overplot the CTD and XCP temperatures, if both exist
if isxcpOK == 1 & isctdOK == 1
figure(2)
subplot(1,2,2)
hold on
plot(ctdtemp, ctddepth, ':')
plot(min(ctdtemp), -botz, '*k')
end

%  get and plot the LADCP profile data;  ladcpno is the same as ctdno
if isctdOK == 1
[isladcpOK, ladcpdepth, ladcpu, ladcpv, shipdepth, shipu, shipv, tidu, tidv] = getladcp(ctdno);
end
if isladcpOK == 1
ladcpdepth = -ladcpdepth;   %  make the depths negative
shipdepth = -shipdepth;
pladcp = sw_pres(-ladcpdepth, lat);    %  compute the pressure
end

if isladcpOK == 1
figure(4)
clf reset

plot(ladcpu, ladcpdepth, ladcpv, ladcpdepth)
hold on
plot(shipu, shipdepth, ':', shipv, shipdepth, ':')      %   these are the ship's adcp data
legend('LADCP east current', 'LADCP north current','ship`s ADCP ', 'ship`s ADCP ', 2)
legend boxoff
xlabel('U, V (cm/sec)')
ylabel('depth, m')
grid
titl = ['LADCP cast  ', num2str(ctdno)];
ht = title(titl);
set(ht, 'FontSize', 14)

hold on
plot(tidu, -5, '*', tidv, -5, '*g')

hold on
plot(0, -botz, '*k')

axis([-100, 100, -zlim 0])

plot([0 0], [-2000 0], 'r', 'linewidth', 0.6)
end    %  if on ladcpOK


%  plot the XCP and LADCP currents together, if both exist
if isxcpOK == 1 & isladcpOK == 1
figure(5)
clf reset

plot(ladcpu, ladcpdepth, ladcpv, ladcpdepth)
hold on
plot(xcpu, xcpdepth, ':', xcpv, xcpdepth, ':')
hold on
plot(0, -botz, '*k')

legend('LADCP east current', 'LADCP north current', ...
    'XCP east ', 'XCP north', 2)
legend boxoff
xlabel('U, V (cm/sec)')
ylabel('depth, m')
grid
titl = ['LADCP cast  ', num2str(ctdno), ' and XCP'];
ht = title(titl);
set(ht, 'FontSize', 14);

hold on
axis([-100, 100, -zlim 0])
plot([0 0], [-2000 0], 'r', 'linewidth', 0.6)
end   %  if on xcp and ladcp

% plot the CTD T and XCP T together
if isxcpOK == 1 & isctdOK == 1    
figure(6)
plot(xcptemp, xcpdepth, ctdtemp, ctddepth, ':')
hold on
plot(min(ctdtemp), -botz, '*k')
grid on
legend('XCP temp', 'CTD temp', 2)
ht = title('XCP and CTD temperature');
set(ht, 'FontSize', 14);

xlabel('Temperature in situ, C')
ylabel('depth, m')
end

%  get nutrient data  (use the ctdno for this)
clear sili nitr phos presnut

if isctdOK == 1
[isnutOK, sili, nitr, phos, presnut] = getnut(ctdno);
if isnutOK == 1 & length(presnut) >= 1
znut = -sw_dpth(presnut, lat);   

figure(6)
clf reset

subplot(1,3,1)
hp = plot(sili(sili > 0), znut(sili > 0), '*');
axis([0 12  -1400 0])
xlabel('silicate')
ylabel('depth, m')
% set(gca, 'YDir', 'reverse')
ht = title('nutrients from bottles');
set(ht, 'FontSize', 14);
subplot(1,3,2)
hp = plot(nitr(nitr > 0), znut(nitr > 0), '*');
axis([0 20  -1400 0])
xlabel('nitrate')
% set(gca, 'YDir', 'reverse')
subplot(1,3,3)
hp = plot(phos(phos > 0), znut(phos > 0), '*');
axis([0 1.2  -1400 0])
xlabel('phosphate')
% set(gca, 'YDir', 'reverse')
end;  end % ifs on isctdOK, isnutOK  



if isladcpOK == 1 & isxcpOK == 1; figure(5); end
if isladcpOK == 1; figure(4); end
if isctdOK == 1;  figure(3); end
if isxcpOK == 1; 
figure(2)
figure(1)
end
if islogOK == 1
figure(7); clf reset   %  this figure is left blank (seems required to be able to 
%   plot on top of the map that comes next - weird.)
open largebasemap.fig
hold on
hh7 = plot(lon, lat, 'r*');
set(hh7,'MarkerSize', 8)
text(lon+0.1, lat, statname)
ccc = [' CTD ' num2str(ctdno)  '   station  ' statname ];
title(ccc)
end
close (7)

pause 

end   %  the loop on mm stations
