function [isxcpOK, cz, cu, cv, ct, varargout] = getxcp(sect)
% fgetxcp.m -- get matlab format xcp profile or profiles. Can be called with
%   either 4 or 9 output arguments. If 4, they are z, u, v and
%   t (each a matrix with one column for each profile). If 8, add
%   time (yearday), latitude, longitude, and bottom depth
%   (vectors with one entry for each profile).
% Optional arguments (for opt) are:
%   'raw' -- don't apply filters, to data (default is to filter)
%   'abs' -- reference to ADCP velocity over 150-250m to get
%            absolute velocity profile
%   'hrs' -- high resolution profile
%
%  sect is a vector of station numbers, one or more.
%
% REMEMBER: XCP velocities (unless Geo) are referenced to magnetic north!
%
% also:
%   cu, cv and verr are in cm/s
%   cz values are negative
%
% Modified for FBC cruise 6/25/00
%  
%  modified to put the path in the main program, not here
%
%  directory path is set in Profile 247

zoff = 0;
xbotoff = 5; % depends on processing used, but generally same as XCP resolution

ext = ['.mat'];
y = 2000; m = 6;
refday = datenum(y,1,1,0,0,0) - 1; % zero point of the year

lat = NaN*sect;
lon = NaN*sect;
mld = NaN*sect;
dep = NaN*sect;

for i = 1:length(sect),

 fname = [sprintf('%0.4i',sect(i)) '.mat']; 
 %   fname = ['xcp' sprintf('%0.4i',sect(i)) '.mat'];
 
 % if ~exist([dir fname])
 if ~exist([fname])
     isxcpOK = 0;
 %   disp(['Station #' num2str(sect(i)) ' does not have an XCP drop.']);
    z = NaN;
    T = NaN;
    u = NaN;
    v = NaN;
    verr = NaN;
    lat(i) = NaN;
    lon(i) = NaN;
    mld(i) = NaN;
    dep(i) = NaN;
  else

    [lat(i), lon(i), mld(i)] = xtimpos(sect(i));

  %  xcp = load([dir fname]);
  
  xcp = load([fname]);

dep(i) = max(xcp.pres) + xbotoff;

z = (-sw_dpth(xcp.pres', lat))';

T = xcp.xcptemp;

    u = xcp.UAbsGeo;
    v = xcp.VAbsGeo;
    
%   verr = xcp.VERR;
verr = xcp.verr;

  end; % if ~exist([dir fname])
      
  if i == 1

    cz = z';
    ct = T';
    cu = u'*100;
    cv = v'*100;
    verr = verr'*100;

  else
    ld = length(z);
    lz = size(cz,1);
    if ld > lz
      pad = nan*ones(ld-lz,i-1);
      cz = [cz; pad];
      ct = [ct; pad];
      cu = [cu; pad];
      cv = [cv; pad];
    else
      z = [z nan*ones(1,lz-ld)];
      T = [T nan*ones(1,lz-ld)];
      u = [u nan*ones(1,lz-ld)];
      v = [v nan*ones(1,lz-ld)];
    end % if ld > lz
    %cz
    %z
    cz = [cz z'];
    ct = [ct T'];
    cu = [cu u'*100];
    cv = [cv v'*100];

  end % if i == 1

  
end % for i = 1:length(sect),

if length(cz) >= 5; isxcpOK = 1; end

doy = mld-refday;

cz = cz + zoff; % correct for seemingly early start in xcppro

if nargout == 9
  varargout(1) = {mld};
  varargout(2) = {lat};
  varargout(3) = {lon};
  varargout(4) = {dep};
elseif nargout == 11
  varargout(1) = {carea};
  varargout(2) = {rotf};
  varargout(3) = {efbl};
  varargout(4) = {ccbl};
  varargout(5) = {verr};
  varargout(6) = {terr};
else
  varargout = {[]};
end % if nargout == 8
return
%
%
%
function [lat, lon, time] = xtimpos(xnum);
% XTIMPOS  Gets xcp drop position and time from names file, given xcp number.
%   [lat, lon, time] = xtimpos(xcpnum)

%  namesfile = '/home/girton/fbc/names';
  namesfile = 'XCPnames.dat';
  
  if ~isstr(xnum)
    fname = ['xcp' num2str(xnum)];
  else
    fname = ['xcp' xnum];
  end
  
  fid = fopen (namesfile);
  if fid<0
    error('cannot open names file')
  end

  while 1
    buf = fgetl(fid);
    if ~isstr(buf), break, end
    tmp = buf;
    [tok1,tmp] = strtok(tmp); % xcpsnd filename
    [tok2,tmp] = strtok(tmp); % xcp drop name
    [tok3,tmp] = strtok(tmp); % date
    [tok4,tmp] = strtok(tmp); % time
    [tok5,tmp] = strtok(tmp); % latitude degrees N
    [tok6,tmp] = strtok(tmp); % latitude minutes
    [tok7,tmp] = strtok(tmp); % longitude degrees W
    [tok8,tmp] = strtok(tmp); % longitude minutes
    
    if(strcmp(tok2,fname))
      yymmdd = tok3;
      hhmmss = tok4;
      latdeg = tok5;
      latmin = tok6;
      londeg = tok7;
      lonmin = tok8;
      break
    end
  end
  fclose(fid);

  yr = str2num(yymmdd(1:2)) + 1900;  if yr < 1980, yr=yr+100; end
  mo = str2num(yymmdd(3:4));
  da = str2num(yymmdd(5:6));
  
  hr = str2num(hhmmss(1:2));
  mi = str2num(hhmmss(3:4));
  se = str2num(hhmmss(5:6));

  time = datenum(yr,mo,da,hr,mi,se);

  lat = str2num(latdeg) + str2num(latmin)/60;
  lon = -(str2num(londeg) + str2num(lonmin)/60);
  
  return
  